==> haskell-hlint-1.9.26-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hlint/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 1.9.26
id: hlint-1.9.26-2cb7c110a1678885cbc52d231f5c0fef
key: hlint_L3CmfRhHwZY50rePR3KF8w
license: BSD3
copyright: Neil Mitchell 2006-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint2
    Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Settings Report Util Parallel Refact HSE.All HSE.Bracket
                HSE.Evaluate HSE.FreeVars HSE.Match HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Extensions
                Hint.Import Hint.Lambda Hint.List Hint.ListRec Hint.Match
                Hint.Monad Hint.Naming Hint.Pragma Hint.Structure Hint.Type
                Hint.Unsafe Hint.Util Test.All Test.Annotations Test.InputOutput
                Test.Proof Test.Translate Test.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.26
library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.26
data-dir: /usr/share/hlint
hs-libraries: HShlint-1.9.26-L3CmfRhHwZY50rePR3KF8w
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    cmdargs-0.10.13-bef2ab6ecde2bd42e13eb0f01d9aba51
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cpphs-1.19.3-8cb6c3761dbbd3c20e10f28974c8d246
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    haskell-src-exts-1.17.1-7afd8d2f109e171c19a1cb4891217e0d
    hscolour-1.23-12df95f4b94c13684d4abc3c2e6b8387
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    refact-0.3.0.2-cdc0b885b64467c207c7798e46520776
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    uniplate-1.6.12-8f24c9f82f93b9dabcf5d8b53ffd592c
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hlint-1.9.26-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hlint/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 1.9.26
id: hlint-1.9.26-c13264b02f49cf69836187748827c12a
key: hlint_D088B7ym2iB7jl4FKzRthX
license: BSD3
copyright: Neil Mitchell 2006-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint2
    Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Settings Report Util Parallel Refact HSE.All HSE.Bracket
                HSE.Evaluate HSE.FreeVars HSE.Match HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Extensions
                Hint.Import Hint.Lambda Hint.List Hint.ListRec Hint.Match
                Hint.Monad Hint.Naming Hint.Pragma Hint.Structure Hint.Type
                Hint.Unsafe Hint.Util Test.All Test.Annotations Test.InputOutput
                Test.Proof Test.Translate Test.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.26
library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.26
data-dir: /usr/share/hlint
hs-libraries: HShlint-1.9.26-D088B7ym2iB7jl4FKzRthX
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    cmdargs-0.10.13-bef2ab6ecde2bd42e13eb0f01d9aba51
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cpphs-1.19.3-8cb6c3761dbbd3c20e10f28974c8d246
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    haskell-src-exts-1.17.1-7afd8d2f109e171c19a1cb4891217e0d
    hscolour-1.24-b1fe788d8499aec980e06c0cdcf38b18
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    refact-0.3.0.2-cdc0b885b64467c207c7798e46520776
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    uniplate-1.6.12-8f24c9f82f93b9dabcf5d8b53ffd592c
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
